oumi.models.experimental.cambrian.model.multimodal\_encoder
===========================================================
.. automodule:: oumi.models.experimental.cambrian.model.multimodal_encoder
   :members:
   :undoc-members:
   :show-inheritance:
